@@ -9,5 +9,4 @@ Description:
 # Welcome to the wedap module! 
 from .h5_pdist import *
 from .h5_plot import *
-from .search_aux import *
-from .h5_plot_trace import *
+from .h5_gif import *
